# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['SecretParameterArgs', 'SecretParameter']

@pulumi.input_type
class SecretParameterArgs:
    def __init__(__self__, *,
                 secret_parameter_name: pulumi.Input[str],
                 value: pulumi.Input[str],
                 constraints: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 key_id: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 type: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a SecretParameter resource.
        :param pulumi.Input[str] secret_parameter_name: The name of the encryption parameter.  The name must be `2` to `180` characters in length, and can contain letters, digits, hyphens (-), forward slashes (/) and underscores (_). It cannot start with `ALIYUN`, `ACS`, `ALIBABA`, `ALICLOUD`, or `OOS`.
        :param pulumi.Input[str] value: The value of the encryption parameter. The value must be `1` to `4096` characters in length.
        :param pulumi.Input[str] constraints: The constraints of the encryption parameter. By default, this parameter is null. Valid values:
               * `AllowedValues`: The value that is allowed for the encryption parameter. It must be an array string.
               * `AllowedPattern`: The pattern that is allowed for the encryption parameter. It must be a regular expression.
               * `MinLength`: The minimum length of the encryption parameter.
               * `MaxLength`: The maximum length of the encryption parameter.
        :param pulumi.Input[str] description: The description of the encryption parameter. The description must be `1` to `200` characters in length.
        :param pulumi.Input[str] key_id: The Customer Master Key (CMK) of Key Management Service (KMS) that is used to encrypt the parameter.
        :param pulumi.Input[str] resource_group_id: The ID of the Resource Group.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] type: The data type of the encryption parameter. Valid values: `Secret`.
        """
        pulumi.set(__self__, "secret_parameter_name", secret_parameter_name)
        pulumi.set(__self__, "value", value)
        if constraints is not None:
            pulumi.set(__self__, "constraints", constraints)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if key_id is not None:
            pulumi.set(__self__, "key_id", key_id)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="secretParameterName")
    def secret_parameter_name(self) -> pulumi.Input[str]:
        """
        The name of the encryption parameter.  The name must be `2` to `180` characters in length, and can contain letters, digits, hyphens (-), forward slashes (/) and underscores (_). It cannot start with `ALIYUN`, `ACS`, `ALIBABA`, `ALICLOUD`, or `OOS`.
        """
        return pulumi.get(self, "secret_parameter_name")

    @secret_parameter_name.setter
    def secret_parameter_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "secret_parameter_name", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[str]:
        """
        The value of the encryption parameter. The value must be `1` to `4096` characters in length.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[str]):
        pulumi.set(self, "value", value)

    @property
    @pulumi.getter
    def constraints(self) -> Optional[pulumi.Input[str]]:
        """
        The constraints of the encryption parameter. By default, this parameter is null. Valid values:
        * `AllowedValues`: The value that is allowed for the encryption parameter. It must be an array string.
        * `AllowedPattern`: The pattern that is allowed for the encryption parameter. It must be a regular expression.
        * `MinLength`: The minimum length of the encryption parameter.
        * `MaxLength`: The maximum length of the encryption parameter.
        """
        return pulumi.get(self, "constraints")

    @constraints.setter
    def constraints(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "constraints", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the encryption parameter. The description must be `1` to `200` characters in length.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="keyId")
    def key_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Customer Master Key (CMK) of Key Management Service (KMS) that is used to encrypt the parameter.
        """
        return pulumi.get(self, "key_id")

    @key_id.setter
    def key_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key_id", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Resource Group.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        The data type of the encryption parameter. Valid values: `Secret`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)


@pulumi.input_type
class _SecretParameterState:
    def __init__(__self__, *,
                 constraints: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 key_id: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 secret_parameter_name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 value: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering SecretParameter resources.
        :param pulumi.Input[str] constraints: The constraints of the encryption parameter. By default, this parameter is null. Valid values:
               * `AllowedValues`: The value that is allowed for the encryption parameter. It must be an array string.
               * `AllowedPattern`: The pattern that is allowed for the encryption parameter. It must be a regular expression.
               * `MinLength`: The minimum length of the encryption parameter.
               * `MaxLength`: The maximum length of the encryption parameter.
        :param pulumi.Input[str] description: The description of the encryption parameter. The description must be `1` to `200` characters in length.
        :param pulumi.Input[str] key_id: The Customer Master Key (CMK) of Key Management Service (KMS) that is used to encrypt the parameter.
        :param pulumi.Input[str] resource_group_id: The ID of the Resource Group.
        :param pulumi.Input[str] secret_parameter_name: The name of the encryption parameter.  The name must be `2` to `180` characters in length, and can contain letters, digits, hyphens (-), forward slashes (/) and underscores (_). It cannot start with `ALIYUN`, `ACS`, `ALIBABA`, `ALICLOUD`, or `OOS`.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] type: The data type of the encryption parameter. Valid values: `Secret`.
        :param pulumi.Input[str] value: The value of the encryption parameter. The value must be `1` to `4096` characters in length.
        """
        if constraints is not None:
            pulumi.set(__self__, "constraints", constraints)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if key_id is not None:
            pulumi.set(__self__, "key_id", key_id)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if secret_parameter_name is not None:
            pulumi.set(__self__, "secret_parameter_name", secret_parameter_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def constraints(self) -> Optional[pulumi.Input[str]]:
        """
        The constraints of the encryption parameter. By default, this parameter is null. Valid values:
        * `AllowedValues`: The value that is allowed for the encryption parameter. It must be an array string.
        * `AllowedPattern`: The pattern that is allowed for the encryption parameter. It must be a regular expression.
        * `MinLength`: The minimum length of the encryption parameter.
        * `MaxLength`: The maximum length of the encryption parameter.
        """
        return pulumi.get(self, "constraints")

    @constraints.setter
    def constraints(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "constraints", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the encryption parameter. The description must be `1` to `200` characters in length.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="keyId")
    def key_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Customer Master Key (CMK) of Key Management Service (KMS) that is used to encrypt the parameter.
        """
        return pulumi.get(self, "key_id")

    @key_id.setter
    def key_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key_id", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Resource Group.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter(name="secretParameterName")
    def secret_parameter_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the encryption parameter.  The name must be `2` to `180` characters in length, and can contain letters, digits, hyphens (-), forward slashes (/) and underscores (_). It cannot start with `ALIYUN`, `ACS`, `ALIBABA`, `ALICLOUD`, or `OOS`.
        """
        return pulumi.get(self, "secret_parameter_name")

    @secret_parameter_name.setter
    def secret_parameter_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secret_parameter_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        The data type of the encryption parameter. Valid values: `Secret`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[str]]:
        """
        The value of the encryption parameter. The value must be `1` to `4096` characters in length.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "value", value)


class SecretParameter(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 constraints: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 key_id: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 secret_parameter_name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 value: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a OOS Secret Parameter resource.

        For information about OOS Secret Parameter and how to use it, see [What is Secret Parameter](https://www.alibabacloud.com/help/en/doc-detail/183418.html).

        > **NOTE:** Available since v1.147.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.resourcemanager.get_resource_groups()
        example_key = alicloud.kms.Key("example",
            description="terraform-example",
            status="Enabled",
            pending_window_in_days=7)
        example_secret_parameter = alicloud.oos.SecretParameter("example",
            secret_parameter_name="terraform-example",
            value="terraform-example",
            type="Secret",
            key_id=example_key.id,
            description="terraform-example",
            tags={
                "Created": "TF",
                "For": "OosSecretParameter",
            },
            resource_group_id=example.groups[0].id)
        ```

        ## Import

        OOS Secret Parameter can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:oos/secretParameter:SecretParameter example <secret_parameter_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] constraints: The constraints of the encryption parameter. By default, this parameter is null. Valid values:
               * `AllowedValues`: The value that is allowed for the encryption parameter. It must be an array string.
               * `AllowedPattern`: The pattern that is allowed for the encryption parameter. It must be a regular expression.
               * `MinLength`: The minimum length of the encryption parameter.
               * `MaxLength`: The maximum length of the encryption parameter.
        :param pulumi.Input[str] description: The description of the encryption parameter. The description must be `1` to `200` characters in length.
        :param pulumi.Input[str] key_id: The Customer Master Key (CMK) of Key Management Service (KMS) that is used to encrypt the parameter.
        :param pulumi.Input[str] resource_group_id: The ID of the Resource Group.
        :param pulumi.Input[str] secret_parameter_name: The name of the encryption parameter.  The name must be `2` to `180` characters in length, and can contain letters, digits, hyphens (-), forward slashes (/) and underscores (_). It cannot start with `ALIYUN`, `ACS`, `ALIBABA`, `ALICLOUD`, or `OOS`.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] type: The data type of the encryption parameter. Valid values: `Secret`.
        :param pulumi.Input[str] value: The value of the encryption parameter. The value must be `1` to `4096` characters in length.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SecretParameterArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a OOS Secret Parameter resource.

        For information about OOS Secret Parameter and how to use it, see [What is Secret Parameter](https://www.alibabacloud.com/help/en/doc-detail/183418.html).

        > **NOTE:** Available since v1.147.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.resourcemanager.get_resource_groups()
        example_key = alicloud.kms.Key("example",
            description="terraform-example",
            status="Enabled",
            pending_window_in_days=7)
        example_secret_parameter = alicloud.oos.SecretParameter("example",
            secret_parameter_name="terraform-example",
            value="terraform-example",
            type="Secret",
            key_id=example_key.id,
            description="terraform-example",
            tags={
                "Created": "TF",
                "For": "OosSecretParameter",
            },
            resource_group_id=example.groups[0].id)
        ```

        ## Import

        OOS Secret Parameter can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:oos/secretParameter:SecretParameter example <secret_parameter_name>
        ```

        :param str resource_name: The name of the resource.
        :param SecretParameterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SecretParameterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 constraints: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 key_id: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 secret_parameter_name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 value: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SecretParameterArgs.__new__(SecretParameterArgs)

            __props__.__dict__["constraints"] = constraints
            __props__.__dict__["description"] = description
            __props__.__dict__["key_id"] = key_id
            __props__.__dict__["resource_group_id"] = resource_group_id
            if secret_parameter_name is None and not opts.urn:
                raise TypeError("Missing required property 'secret_parameter_name'")
            __props__.__dict__["secret_parameter_name"] = secret_parameter_name
            __props__.__dict__["tags"] = tags
            __props__.__dict__["type"] = type
            if value is None and not opts.urn:
                raise TypeError("Missing required property 'value'")
            __props__.__dict__["value"] = None if value is None else pulumi.Output.secret(value)
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["value"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(SecretParameter, __self__).__init__(
            'alicloud:oos/secretParameter:SecretParameter',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            constraints: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            key_id: Optional[pulumi.Input[str]] = None,
            resource_group_id: Optional[pulumi.Input[str]] = None,
            secret_parameter_name: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            type: Optional[pulumi.Input[str]] = None,
            value: Optional[pulumi.Input[str]] = None) -> 'SecretParameter':
        """
        Get an existing SecretParameter resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] constraints: The constraints of the encryption parameter. By default, this parameter is null. Valid values:
               * `AllowedValues`: The value that is allowed for the encryption parameter. It must be an array string.
               * `AllowedPattern`: The pattern that is allowed for the encryption parameter. It must be a regular expression.
               * `MinLength`: The minimum length of the encryption parameter.
               * `MaxLength`: The maximum length of the encryption parameter.
        :param pulumi.Input[str] description: The description of the encryption parameter. The description must be `1` to `200` characters in length.
        :param pulumi.Input[str] key_id: The Customer Master Key (CMK) of Key Management Service (KMS) that is used to encrypt the parameter.
        :param pulumi.Input[str] resource_group_id: The ID of the Resource Group.
        :param pulumi.Input[str] secret_parameter_name: The name of the encryption parameter.  The name must be `2` to `180` characters in length, and can contain letters, digits, hyphens (-), forward slashes (/) and underscores (_). It cannot start with `ALIYUN`, `ACS`, `ALIBABA`, `ALICLOUD`, or `OOS`.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] type: The data type of the encryption parameter. Valid values: `Secret`.
        :param pulumi.Input[str] value: The value of the encryption parameter. The value must be `1` to `4096` characters in length.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SecretParameterState.__new__(_SecretParameterState)

        __props__.__dict__["constraints"] = constraints
        __props__.__dict__["description"] = description
        __props__.__dict__["key_id"] = key_id
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["secret_parameter_name"] = secret_parameter_name
        __props__.__dict__["tags"] = tags
        __props__.__dict__["type"] = type
        __props__.__dict__["value"] = value
        return SecretParameter(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def constraints(self) -> pulumi.Output[Optional[str]]:
        """
        The constraints of the encryption parameter. By default, this parameter is null. Valid values:
        * `AllowedValues`: The value that is allowed for the encryption parameter. It must be an array string.
        * `AllowedPattern`: The pattern that is allowed for the encryption parameter. It must be a regular expression.
        * `MinLength`: The minimum length of the encryption parameter.
        * `MaxLength`: The maximum length of the encryption parameter.
        """
        return pulumi.get(self, "constraints")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the encryption parameter. The description must be `1` to `200` characters in length.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="keyId")
    def key_id(self) -> pulumi.Output[Optional[str]]:
        """
        The Customer Master Key (CMK) of Key Management Service (KMS) that is used to encrypt the parameter.
        """
        return pulumi.get(self, "key_id")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[str]:
        """
        The ID of the Resource Group.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="secretParameterName")
    def secret_parameter_name(self) -> pulumi.Output[str]:
        """
        The name of the encryption parameter.  The name must be `2` to `180` characters in length, and can contain letters, digits, hyphens (-), forward slashes (/) and underscores (_). It cannot start with `ALIYUN`, `ACS`, `ALIBABA`, `ALICLOUD`, or `OOS`.
        """
        return pulumi.get(self, "secret_parameter_name")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[str]:
        """
        The data type of the encryption parameter. Valid values: `Secret`.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def value(self) -> pulumi.Output[str]:
        """
        The value of the encryption parameter. The value must be `1` to `4096` characters in length.
        """
        return pulumi.get(self, "value")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetKubernetesPermissionResult',
    'AwaitableGetKubernetesPermissionResult',
    'get_kubernetes_permission',
    'get_kubernetes_permission_output',
]

@pulumi.output_type
class GetKubernetesPermissionResult:
    """
    A collection of values returned by getKubernetesPermission.
    """
    def __init__(__self__, id=None, permissions=None, uid=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if permissions and not isinstance(permissions, list):
            raise TypeError("Expected argument 'permissions' to be a list")
        pulumi.set(__self__, "permissions", permissions)
        if uid and not isinstance(uid, str):
            raise TypeError("Expected argument 'uid' to be a str")
        pulumi.set(__self__, "uid", uid)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def permissions(self) -> Sequence['outputs.GetKubernetesPermissionPermissionResult']:
        """
        A list of user permission. See `permissions` below.
        """
        return pulumi.get(self, "permissions")

    @property
    @pulumi.getter
    def uid(self) -> str:
        """
        The ID of the RAM user. If you want to query the permissions of a RAM role, specify the ID of the RAM role.
        """
        return pulumi.get(self, "uid")


class AwaitableGetKubernetesPermissionResult(GetKubernetesPermissionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetKubernetesPermissionResult(
            id=self.id,
            permissions=self.permissions,
            uid=self.uid)


def get_kubernetes_permission(uid: Optional[str] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetKubernetesPermissionResult:
    """
    This data source provides a list of Ram user permissions.

    > **NOTE:** Available since v1.122.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    # Declare the data source
    default = alicloud.ram.get_users()
    # permissions
    default_get_kubernetes_permission = alicloud.cs.get_kubernetes_permission(uid=default.users[0].id)
    pulumi.export("permissions", default_get_kubernetes_permission.permissions)
    ```


    :param str uid: The ID of the RAM user. If you want to query the permissions of a RAM role, specify the ID of the RAM role.
    """
    __args__ = dict()
    __args__['uid'] = uid
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:cs/getKubernetesPermission:getKubernetesPermission', __args__, opts=opts, typ=GetKubernetesPermissionResult).value

    return AwaitableGetKubernetesPermissionResult(
        id=pulumi.get(__ret__, 'id'),
        permissions=pulumi.get(__ret__, 'permissions'),
        uid=pulumi.get(__ret__, 'uid'))
def get_kubernetes_permission_output(uid: Optional[pulumi.Input[str]] = None,
                                     opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetKubernetesPermissionResult]:
    """
    This data source provides a list of Ram user permissions.

    > **NOTE:** Available since v1.122.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    # Declare the data source
    default = alicloud.ram.get_users()
    # permissions
    default_get_kubernetes_permission = alicloud.cs.get_kubernetes_permission(uid=default.users[0].id)
    pulumi.export("permissions", default_get_kubernetes_permission.permissions)
    ```


    :param str uid: The ID of the RAM user. If you want to query the permissions of a RAM role, specify the ID of the RAM role.
    """
    __args__ = dict()
    __args__['uid'] = uid
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:cs/getKubernetesPermission:getKubernetesPermission', __args__, opts=opts, typ=GetKubernetesPermissionResult)
    return __ret__.apply(lambda __response__: GetKubernetesPermissionResult(
        id=pulumi.get(__response__, 'id'),
        permissions=pulumi.get(__response__, 'permissions'),
        uid=pulumi.get(__response__, 'uid')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['CollectionPolicyArgs', 'CollectionPolicy']

@pulumi.input_type
class CollectionPolicyArgs:
    def __init__(__self__, *,
                 data_code: pulumi.Input[str],
                 enabled: pulumi.Input[bool],
                 policy_config: pulumi.Input['CollectionPolicyPolicyConfigArgs'],
                 policy_name: pulumi.Input[str],
                 product_code: pulumi.Input[str],
                 centralize_config: Optional[pulumi.Input['CollectionPolicyCentralizeConfigArgs']] = None,
                 centralize_enabled: Optional[pulumi.Input[bool]] = None,
                 data_config: Optional[pulumi.Input['CollectionPolicyDataConfigArgs']] = None,
                 resource_directory: Optional[pulumi.Input['CollectionPolicyResourceDirectoryArgs']] = None):
        """
        The set of arguments for constructing a CollectionPolicy resource.
        :param pulumi.Input[str] data_code: Log type encoding.
        :param pulumi.Input[bool] enabled: Whether to open.
        :param pulumi.Input['CollectionPolicyPolicyConfigArgs'] policy_config: Collection rule configuration. See `policy_config` below.
        :param pulumi.Input[str] policy_name: The name of the rule, with a minimum of 3 characters and a maximum of 63 characters, must start with a letter.
        :param pulumi.Input[str] product_code: Product code.
        :param pulumi.Input['CollectionPolicyCentralizeConfigArgs'] centralize_config: Centralized transfer configuration. See `centralize_config` below.
        :param pulumi.Input[bool] centralize_enabled: Whether to enable centralized Conversion. The default value is false.
        :param pulumi.Input['CollectionPolicyDataConfigArgs'] data_config: The configuration is supported only when the log type is global. For example, if the productCode is sls, global logs will be collected to the corresponding region during the first configuration. See `data_config` below.
        :param pulumi.Input['CollectionPolicyResourceDirectoryArgs'] resource_directory: For Resource Directory configuration, the account must have opened the resource directory and be an administrator or a delegated administrator. See `resource_directory` below.
        """
        pulumi.set(__self__, "data_code", data_code)
        pulumi.set(__self__, "enabled", enabled)
        pulumi.set(__self__, "policy_config", policy_config)
        pulumi.set(__self__, "policy_name", policy_name)
        pulumi.set(__self__, "product_code", product_code)
        if centralize_config is not None:
            pulumi.set(__self__, "centralize_config", centralize_config)
        if centralize_enabled is not None:
            pulumi.set(__self__, "centralize_enabled", centralize_enabled)
        if data_config is not None:
            pulumi.set(__self__, "data_config", data_config)
        if resource_directory is not None:
            pulumi.set(__self__, "resource_directory", resource_directory)

    @property
    @pulumi.getter(name="dataCode")
    def data_code(self) -> pulumi.Input[str]:
        """
        Log type encoding.
        """
        return pulumi.get(self, "data_code")

    @data_code.setter
    def data_code(self, value: pulumi.Input[str]):
        pulumi.set(self, "data_code", value)

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Input[bool]:
        """
        Whether to open.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: pulumi.Input[bool]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="policyConfig")
    def policy_config(self) -> pulumi.Input['CollectionPolicyPolicyConfigArgs']:
        """
        Collection rule configuration. See `policy_config` below.
        """
        return pulumi.get(self, "policy_config")

    @policy_config.setter
    def policy_config(self, value: pulumi.Input['CollectionPolicyPolicyConfigArgs']):
        pulumi.set(self, "policy_config", value)

    @property
    @pulumi.getter(name="policyName")
    def policy_name(self) -> pulumi.Input[str]:
        """
        The name of the rule, with a minimum of 3 characters and a maximum of 63 characters, must start with a letter.
        """
        return pulumi.get(self, "policy_name")

    @policy_name.setter
    def policy_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "policy_name", value)

    @property
    @pulumi.getter(name="productCode")
    def product_code(self) -> pulumi.Input[str]:
        """
        Product code.
        """
        return pulumi.get(self, "product_code")

    @product_code.setter
    def product_code(self, value: pulumi.Input[str]):
        pulumi.set(self, "product_code", value)

    @property
    @pulumi.getter(name="centralizeConfig")
    def centralize_config(self) -> Optional[pulumi.Input['CollectionPolicyCentralizeConfigArgs']]:
        """
        Centralized transfer configuration. See `centralize_config` below.
        """
        return pulumi.get(self, "centralize_config")

    @centralize_config.setter
    def centralize_config(self, value: Optional[pulumi.Input['CollectionPolicyCentralizeConfigArgs']]):
        pulumi.set(self, "centralize_config", value)

    @property
    @pulumi.getter(name="centralizeEnabled")
    def centralize_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to enable centralized Conversion. The default value is false.
        """
        return pulumi.get(self, "centralize_enabled")

    @centralize_enabled.setter
    def centralize_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "centralize_enabled", value)

    @property
    @pulumi.getter(name="dataConfig")
    def data_config(self) -> Optional[pulumi.Input['CollectionPolicyDataConfigArgs']]:
        """
        The configuration is supported only when the log type is global. For example, if the productCode is sls, global logs will be collected to the corresponding region during the first configuration. See `data_config` below.
        """
        return pulumi.get(self, "data_config")

    @data_config.setter
    def data_config(self, value: Optional[pulumi.Input['CollectionPolicyDataConfigArgs']]):
        pulumi.set(self, "data_config", value)

    @property
    @pulumi.getter(name="resourceDirectory")
    def resource_directory(self) -> Optional[pulumi.Input['CollectionPolicyResourceDirectoryArgs']]:
        """
        For Resource Directory configuration, the account must have opened the resource directory and be an administrator or a delegated administrator. See `resource_directory` below.
        """
        return pulumi.get(self, "resource_directory")

    @resource_directory.setter
    def resource_directory(self, value: Optional[pulumi.Input['CollectionPolicyResourceDirectoryArgs']]):
        pulumi.set(self, "resource_directory", value)


@pulumi.input_type
class _CollectionPolicyState:
    def __init__(__self__, *,
                 centralize_config: Optional[pulumi.Input['CollectionPolicyCentralizeConfigArgs']] = None,
                 centralize_enabled: Optional[pulumi.Input[bool]] = None,
                 data_code: Optional[pulumi.Input[str]] = None,
                 data_config: Optional[pulumi.Input['CollectionPolicyDataConfigArgs']] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 policy_config: Optional[pulumi.Input['CollectionPolicyPolicyConfigArgs']] = None,
                 policy_name: Optional[pulumi.Input[str]] = None,
                 product_code: Optional[pulumi.Input[str]] = None,
                 resource_directory: Optional[pulumi.Input['CollectionPolicyResourceDirectoryArgs']] = None):
        """
        Input properties used for looking up and filtering CollectionPolicy resources.
        :param pulumi.Input['CollectionPolicyCentralizeConfigArgs'] centralize_config: Centralized transfer configuration. See `centralize_config` below.
        :param pulumi.Input[bool] centralize_enabled: Whether to enable centralized Conversion. The default value is false.
        :param pulumi.Input[str] data_code: Log type encoding.
        :param pulumi.Input['CollectionPolicyDataConfigArgs'] data_config: The configuration is supported only when the log type is global. For example, if the productCode is sls, global logs will be collected to the corresponding region during the first configuration. See `data_config` below.
        :param pulumi.Input[bool] enabled: Whether to open.
        :param pulumi.Input['CollectionPolicyPolicyConfigArgs'] policy_config: Collection rule configuration. See `policy_config` below.
        :param pulumi.Input[str] policy_name: The name of the rule, with a minimum of 3 characters and a maximum of 63 characters, must start with a letter.
        :param pulumi.Input[str] product_code: Product code.
        :param pulumi.Input['CollectionPolicyResourceDirectoryArgs'] resource_directory: For Resource Directory configuration, the account must have opened the resource directory and be an administrator or a delegated administrator. See `resource_directory` below.
        """
        if centralize_config is not None:
            pulumi.set(__self__, "centralize_config", centralize_config)
        if centralize_enabled is not None:
            pulumi.set(__self__, "centralize_enabled", centralize_enabled)
        if data_code is not None:
            pulumi.set(__self__, "data_code", data_code)
        if data_config is not None:
            pulumi.set(__self__, "data_config", data_config)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if policy_config is not None:
            pulumi.set(__self__, "policy_config", policy_config)
        if policy_name is not None:
            pulumi.set(__self__, "policy_name", policy_name)
        if product_code is not None:
            pulumi.set(__self__, "product_code", product_code)
        if resource_directory is not None:
            pulumi.set(__self__, "resource_directory", resource_directory)

    @property
    @pulumi.getter(name="centralizeConfig")
    def centralize_config(self) -> Optional[pulumi.Input['CollectionPolicyCentralizeConfigArgs']]:
        """
        Centralized transfer configuration. See `centralize_config` below.
        """
        return pulumi.get(self, "centralize_config")

    @centralize_config.setter
    def centralize_config(self, value: Optional[pulumi.Input['CollectionPolicyCentralizeConfigArgs']]):
        pulumi.set(self, "centralize_config", value)

    @property
    @pulumi.getter(name="centralizeEnabled")
    def centralize_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to enable centralized Conversion. The default value is false.
        """
        return pulumi.get(self, "centralize_enabled")

    @centralize_enabled.setter
    def centralize_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "centralize_enabled", value)

    @property
    @pulumi.getter(name="dataCode")
    def data_code(self) -> Optional[pulumi.Input[str]]:
        """
        Log type encoding.
        """
        return pulumi.get(self, "data_code")

    @data_code.setter
    def data_code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "data_code", value)

    @property
    @pulumi.getter(name="dataConfig")
    def data_config(self) -> Optional[pulumi.Input['CollectionPolicyDataConfigArgs']]:
        """
        The configuration is supported only when the log type is global. For example, if the productCode is sls, global logs will be collected to the corresponding region during the first configuration. See `data_config` below.
        """
        return pulumi.get(self, "data_config")

    @data_config.setter
    def data_config(self, value: Optional[pulumi.Input['CollectionPolicyDataConfigArgs']]):
        pulumi.set(self, "data_config", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to open.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="policyConfig")
    def policy_config(self) -> Optional[pulumi.Input['CollectionPolicyPolicyConfigArgs']]:
        """
        Collection rule configuration. See `policy_config` below.
        """
        return pulumi.get(self, "policy_config")

    @policy_config.setter
    def policy_config(self, value: Optional[pulumi.Input['CollectionPolicyPolicyConfigArgs']]):
        pulumi.set(self, "policy_config", value)

    @property
    @pulumi.getter(name="policyName")
    def policy_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the rule, with a minimum of 3 characters and a maximum of 63 characters, must start with a letter.
        """
        return pulumi.get(self, "policy_name")

    @policy_name.setter
    def policy_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "policy_name", value)

    @property
    @pulumi.getter(name="productCode")
    def product_code(self) -> Optional[pulumi.Input[str]]:
        """
        Product code.
        """
        return pulumi.get(self, "product_code")

    @product_code.setter
    def product_code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "product_code", value)

    @property
    @pulumi.getter(name="resourceDirectory")
    def resource_directory(self) -> Optional[pulumi.Input['CollectionPolicyResourceDirectoryArgs']]:
        """
        For Resource Directory configuration, the account must have opened the resource directory and be an administrator or a delegated administrator. See `resource_directory` below.
        """
        return pulumi.get(self, "resource_directory")

    @resource_directory.setter
    def resource_directory(self, value: Optional[pulumi.Input['CollectionPolicyResourceDirectoryArgs']]):
        pulumi.set(self, "resource_directory", value)


class CollectionPolicy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 centralize_config: Optional[pulumi.Input[Union['CollectionPolicyCentralizeConfigArgs', 'CollectionPolicyCentralizeConfigArgsDict']]] = None,
                 centralize_enabled: Optional[pulumi.Input[bool]] = None,
                 data_code: Optional[pulumi.Input[str]] = None,
                 data_config: Optional[pulumi.Input[Union['CollectionPolicyDataConfigArgs', 'CollectionPolicyDataConfigArgsDict']]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 policy_config: Optional[pulumi.Input[Union['CollectionPolicyPolicyConfigArgs', 'CollectionPolicyPolicyConfigArgsDict']]] = None,
                 policy_name: Optional[pulumi.Input[str]] = None,
                 product_code: Optional[pulumi.Input[str]] = None,
                 resource_directory: Optional[pulumi.Input[Union['CollectionPolicyResourceDirectoryArgs', 'CollectionPolicyResourceDirectoryArgsDict']]] = None,
                 __props__=None):
        """
        Provides a SLS Collection Policy resource.

        Orchestration policies for cloud product log collection.

        For information about SLS Collection Policy and how to use it, see [What is Collection Policy](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.232.0.

        ## Import

        SLS Collection Policy can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:sls/collectionPolicy:CollectionPolicy example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['CollectionPolicyCentralizeConfigArgs', 'CollectionPolicyCentralizeConfigArgsDict']] centralize_config: Centralized transfer configuration. See `centralize_config` below.
        :param pulumi.Input[bool] centralize_enabled: Whether to enable centralized Conversion. The default value is false.
        :param pulumi.Input[str] data_code: Log type encoding.
        :param pulumi.Input[Union['CollectionPolicyDataConfigArgs', 'CollectionPolicyDataConfigArgsDict']] data_config: The configuration is supported only when the log type is global. For example, if the productCode is sls, global logs will be collected to the corresponding region during the first configuration. See `data_config` below.
        :param pulumi.Input[bool] enabled: Whether to open.
        :param pulumi.Input[Union['CollectionPolicyPolicyConfigArgs', 'CollectionPolicyPolicyConfigArgsDict']] policy_config: Collection rule configuration. See `policy_config` below.
        :param pulumi.Input[str] policy_name: The name of the rule, with a minimum of 3 characters and a maximum of 63 characters, must start with a letter.
        :param pulumi.Input[str] product_code: Product code.
        :param pulumi.Input[Union['CollectionPolicyResourceDirectoryArgs', 'CollectionPolicyResourceDirectoryArgsDict']] resource_directory: For Resource Directory configuration, the account must have opened the resource directory and be an administrator or a delegated administrator. See `resource_directory` below.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CollectionPolicyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a SLS Collection Policy resource.

        Orchestration policies for cloud product log collection.

        For information about SLS Collection Policy and how to use it, see [What is Collection Policy](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.232.0.

        ## Import

        SLS Collection Policy can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:sls/collectionPolicy:CollectionPolicy example <id>
        ```

        :param str resource_name: The name of the resource.
        :param CollectionPolicyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CollectionPolicyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 centralize_config: Optional[pulumi.Input[Union['CollectionPolicyCentralizeConfigArgs', 'CollectionPolicyCentralizeConfigArgsDict']]] = None,
                 centralize_enabled: Optional[pulumi.Input[bool]] = None,
                 data_code: Optional[pulumi.Input[str]] = None,
                 data_config: Optional[pulumi.Input[Union['CollectionPolicyDataConfigArgs', 'CollectionPolicyDataConfigArgsDict']]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 policy_config: Optional[pulumi.Input[Union['CollectionPolicyPolicyConfigArgs', 'CollectionPolicyPolicyConfigArgsDict']]] = None,
                 policy_name: Optional[pulumi.Input[str]] = None,
                 product_code: Optional[pulumi.Input[str]] = None,
                 resource_directory: Optional[pulumi.Input[Union['CollectionPolicyResourceDirectoryArgs', 'CollectionPolicyResourceDirectoryArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CollectionPolicyArgs.__new__(CollectionPolicyArgs)

            __props__.__dict__["centralize_config"] = centralize_config
            __props__.__dict__["centralize_enabled"] = centralize_enabled
            if data_code is None and not opts.urn:
                raise TypeError("Missing required property 'data_code'")
            __props__.__dict__["data_code"] = data_code
            __props__.__dict__["data_config"] = data_config
            if enabled is None and not opts.urn:
                raise TypeError("Missing required property 'enabled'")
            __props__.__dict__["enabled"] = enabled
            if policy_config is None and not opts.urn:
                raise TypeError("Missing required property 'policy_config'")
            __props__.__dict__["policy_config"] = policy_config
            if policy_name is None and not opts.urn:
                raise TypeError("Missing required property 'policy_name'")
            __props__.__dict__["policy_name"] = policy_name
            if product_code is None and not opts.urn:
                raise TypeError("Missing required property 'product_code'")
            __props__.__dict__["product_code"] = product_code
            __props__.__dict__["resource_directory"] = resource_directory
        super(CollectionPolicy, __self__).__init__(
            'alicloud:sls/collectionPolicy:CollectionPolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            centralize_config: Optional[pulumi.Input[Union['CollectionPolicyCentralizeConfigArgs', 'CollectionPolicyCentralizeConfigArgsDict']]] = None,
            centralize_enabled: Optional[pulumi.Input[bool]] = None,
            data_code: Optional[pulumi.Input[str]] = None,
            data_config: Optional[pulumi.Input[Union['CollectionPolicyDataConfigArgs', 'CollectionPolicyDataConfigArgsDict']]] = None,
            enabled: Optional[pulumi.Input[bool]] = None,
            policy_config: Optional[pulumi.Input[Union['CollectionPolicyPolicyConfigArgs', 'CollectionPolicyPolicyConfigArgsDict']]] = None,
            policy_name: Optional[pulumi.Input[str]] = None,
            product_code: Optional[pulumi.Input[str]] = None,
            resource_directory: Optional[pulumi.Input[Union['CollectionPolicyResourceDirectoryArgs', 'CollectionPolicyResourceDirectoryArgsDict']]] = None) -> 'CollectionPolicy':
        """
        Get an existing CollectionPolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['CollectionPolicyCentralizeConfigArgs', 'CollectionPolicyCentralizeConfigArgsDict']] centralize_config: Centralized transfer configuration. See `centralize_config` below.
        :param pulumi.Input[bool] centralize_enabled: Whether to enable centralized Conversion. The default value is false.
        :param pulumi.Input[str] data_code: Log type encoding.
        :param pulumi.Input[Union['CollectionPolicyDataConfigArgs', 'CollectionPolicyDataConfigArgsDict']] data_config: The configuration is supported only when the log type is global. For example, if the productCode is sls, global logs will be collected to the corresponding region during the first configuration. See `data_config` below.
        :param pulumi.Input[bool] enabled: Whether to open.
        :param pulumi.Input[Union['CollectionPolicyPolicyConfigArgs', 'CollectionPolicyPolicyConfigArgsDict']] policy_config: Collection rule configuration. See `policy_config` below.
        :param pulumi.Input[str] policy_name: The name of the rule, with a minimum of 3 characters and a maximum of 63 characters, must start with a letter.
        :param pulumi.Input[str] product_code: Product code.
        :param pulumi.Input[Union['CollectionPolicyResourceDirectoryArgs', 'CollectionPolicyResourceDirectoryArgsDict']] resource_directory: For Resource Directory configuration, the account must have opened the resource directory and be an administrator or a delegated administrator. See `resource_directory` below.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CollectionPolicyState.__new__(_CollectionPolicyState)

        __props__.__dict__["centralize_config"] = centralize_config
        __props__.__dict__["centralize_enabled"] = centralize_enabled
        __props__.__dict__["data_code"] = data_code
        __props__.__dict__["data_config"] = data_config
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["policy_config"] = policy_config
        __props__.__dict__["policy_name"] = policy_name
        __props__.__dict__["product_code"] = product_code
        __props__.__dict__["resource_directory"] = resource_directory
        return CollectionPolicy(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="centralizeConfig")
    def centralize_config(self) -> pulumi.Output['outputs.CollectionPolicyCentralizeConfig']:
        """
        Centralized transfer configuration. See `centralize_config` below.
        """
        return pulumi.get(self, "centralize_config")

    @property
    @pulumi.getter(name="centralizeEnabled")
    def centralize_enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether to enable centralized Conversion. The default value is false.
        """
        return pulumi.get(self, "centralize_enabled")

    @property
    @pulumi.getter(name="dataCode")
    def data_code(self) -> pulumi.Output[str]:
        """
        Log type encoding.
        """
        return pulumi.get(self, "data_code")

    @property
    @pulumi.getter(name="dataConfig")
    def data_config(self) -> pulumi.Output['outputs.CollectionPolicyDataConfig']:
        """
        The configuration is supported only when the log type is global. For example, if the productCode is sls, global logs will be collected to the corresponding region during the first configuration. See `data_config` below.
        """
        return pulumi.get(self, "data_config")

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[bool]:
        """
        Whether to open.
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="policyConfig")
    def policy_config(self) -> pulumi.Output['outputs.CollectionPolicyPolicyConfig']:
        """
        Collection rule configuration. See `policy_config` below.
        """
        return pulumi.get(self, "policy_config")

    @property
    @pulumi.getter(name="policyName")
    def policy_name(self) -> pulumi.Output[str]:
        """
        The name of the rule, with a minimum of 3 characters and a maximum of 63 characters, must start with a letter.
        """
        return pulumi.get(self, "policy_name")

    @property
    @pulumi.getter(name="productCode")
    def product_code(self) -> pulumi.Output[str]:
        """
        Product code.
        """
        return pulumi.get(self, "product_code")

    @property
    @pulumi.getter(name="resourceDirectory")
    def resource_directory(self) -> pulumi.Output['outputs.CollectionPolicyResourceDirectory']:
        """
        For Resource Directory configuration, the account must have opened the resource directory and be an administrator or a delegated administrator. See `resource_directory` below.
        """
        return pulumi.get(self, "resource_directory")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetAgentsAgentResult',
]

@pulumi.output_type
class GetAgentsAgentResult(dict):
    def __init__(__self__, *,
                 agent_id: str,
                 agent_key: str,
                 agent_name: str,
                 id: str):
        """
        :param str agent_id: The agent id.
        :param str agent_key: Service space signature, which is used when PAAS interface specifies the service space.
        :param str agent_name: The name of the agent.
        :param str id: ID of the agent.
        """
        pulumi.set(__self__, "agent_id", agent_id)
        pulumi.set(__self__, "agent_key", agent_key)
        pulumi.set(__self__, "agent_name", agent_name)
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="agentId")
    def agent_id(self) -> str:
        """
        The agent id.
        """
        return pulumi.get(self, "agent_id")

    @property
    @pulumi.getter(name="agentKey")
    def agent_key(self) -> str:
        """
        Service space signature, which is used when PAAS interface specifies the service space.
        """
        return pulumi.get(self, "agent_key")

    @property
    @pulumi.getter(name="agentName")
    def agent_name(self) -> str:
        """
        The name of the agent.
        """
        return pulumi.get(self, "agent_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        ID of the agent.
        """
        return pulumi.get(self, "id")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['LifecycleHookArgs', 'LifecycleHook']

@pulumi.input_type
class LifecycleHookArgs:
    def __init__(__self__, *,
                 lifecycle_transition: pulumi.Input[str],
                 scaling_group_id: pulumi.Input[str],
                 default_result: Optional[pulumi.Input[str]] = None,
                 heartbeat_timeout: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 notification_arn: Optional[pulumi.Input[str]] = None,
                 notification_metadata: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a LifecycleHook resource.
        :param pulumi.Input[str] lifecycle_transition: Type of Scaling activity attached to lifecycle hook. Supported value: SCALE_OUT, SCALE_IN.
        :param pulumi.Input[str] scaling_group_id: The ID of the Auto Scaling group to which you want to assign the lifecycle hook.
        :param pulumi.Input[str] default_result: Defines the action the Auto Scaling group should take when the lifecycle hook timeout elapses. Applicable value: CONTINUE, ABANDON, ROLLBACK, default value: CONTINUE.
        :param pulumi.Input[int] heartbeat_timeout: Defines the amount of time, in seconds, that can elapse before the lifecycle hook times out. When the lifecycle hook times out, Auto Scaling performs the action defined in the default_result parameter. Default value: 600.
        :param pulumi.Input[str] name: The name of the lifecycle hook, which must contain 2-64 characters (English or Chinese), starting with numbers, English letters or Chinese characters, and can contain number, underscores `_`, hypens `-`, and decimal point `.`. If this parameter value is not specified, the default value is lifecycle hook id.
        :param pulumi.Input[str] notification_arn: The Arn of notification target.
        :param pulumi.Input[str] notification_metadata: Additional information that you want to include when Auto Scaling sends a message to the notification target.
        """
        pulumi.set(__self__, "lifecycle_transition", lifecycle_transition)
        pulumi.set(__self__, "scaling_group_id", scaling_group_id)
        if default_result is not None:
            pulumi.set(__self__, "default_result", default_result)
        if heartbeat_timeout is not None:
            pulumi.set(__self__, "heartbeat_timeout", heartbeat_timeout)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if notification_arn is not None:
            pulumi.set(__self__, "notification_arn", notification_arn)
        if notification_metadata is not None:
            pulumi.set(__self__, "notification_metadata", notification_metadata)

    @property
    @pulumi.getter(name="lifecycleTransition")
    def lifecycle_transition(self) -> pulumi.Input[str]:
        """
        Type of Scaling activity attached to lifecycle hook. Supported value: SCALE_OUT, SCALE_IN.
        """
        return pulumi.get(self, "lifecycle_transition")

    @lifecycle_transition.setter
    def lifecycle_transition(self, value: pulumi.Input[str]):
        pulumi.set(self, "lifecycle_transition", value)

    @property
    @pulumi.getter(name="scalingGroupId")
    def scaling_group_id(self) -> pulumi.Input[str]:
        """
        The ID of the Auto Scaling group to which you want to assign the lifecycle hook.
        """
        return pulumi.get(self, "scaling_group_id")

    @scaling_group_id.setter
    def scaling_group_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "scaling_group_id", value)

    @property
    @pulumi.getter(name="defaultResult")
    def default_result(self) -> Optional[pulumi.Input[str]]:
        """
        Defines the action the Auto Scaling group should take when the lifecycle hook timeout elapses. Applicable value: CONTINUE, ABANDON, ROLLBACK, default value: CONTINUE.
        """
        return pulumi.get(self, "default_result")

    @default_result.setter
    def default_result(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "default_result", value)

    @property
    @pulumi.getter(name="heartbeatTimeout")
    def heartbeat_timeout(self) -> Optional[pulumi.Input[int]]:
        """
        Defines the amount of time, in seconds, that can elapse before the lifecycle hook times out. When the lifecycle hook times out, Auto Scaling performs the action defined in the default_result parameter. Default value: 600.
        """
        return pulumi.get(self, "heartbeat_timeout")

    @heartbeat_timeout.setter
    def heartbeat_timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "heartbeat_timeout", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the lifecycle hook, which must contain 2-64 characters (English or Chinese), starting with numbers, English letters or Chinese characters, and can contain number, underscores `_`, hypens `-`, and decimal point `.`. If this parameter value is not specified, the default value is lifecycle hook id.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="notificationArn")
    def notification_arn(self) -> Optional[pulumi.Input[str]]:
        """
        The Arn of notification target.
        """
        return pulumi.get(self, "notification_arn")

    @notification_arn.setter
    def notification_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "notification_arn", value)

    @property
    @pulumi.getter(name="notificationMetadata")
    def notification_metadata(self) -> Optional[pulumi.Input[str]]:
        """
        Additional information that you want to include when Auto Scaling sends a message to the notification target.
        """
        return pulumi.get(self, "notification_metadata")

    @notification_metadata.setter
    def notification_metadata(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "notification_metadata", value)


@pulumi.input_type
class _LifecycleHookState:
    def __init__(__self__, *,
                 default_result: Optional[pulumi.Input[str]] = None,
                 heartbeat_timeout: Optional[pulumi.Input[int]] = None,
                 lifecycle_transition: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 notification_arn: Optional[pulumi.Input[str]] = None,
                 notification_metadata: Optional[pulumi.Input[str]] = None,
                 scaling_group_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering LifecycleHook resources.
        :param pulumi.Input[str] default_result: Defines the action the Auto Scaling group should take when the lifecycle hook timeout elapses. Applicable value: CONTINUE, ABANDON, ROLLBACK, default value: CONTINUE.
        :param pulumi.Input[int] heartbeat_timeout: Defines the amount of time, in seconds, that can elapse before the lifecycle hook times out. When the lifecycle hook times out, Auto Scaling performs the action defined in the default_result parameter. Default value: 600.
        :param pulumi.Input[str] lifecycle_transition: Type of Scaling activity attached to lifecycle hook. Supported value: SCALE_OUT, SCALE_IN.
        :param pulumi.Input[str] name: The name of the lifecycle hook, which must contain 2-64 characters (English or Chinese), starting with numbers, English letters or Chinese characters, and can contain number, underscores `_`, hypens `-`, and decimal point `.`. If this parameter value is not specified, the default value is lifecycle hook id.
        :param pulumi.Input[str] notification_arn: The Arn of notification target.
        :param pulumi.Input[str] notification_metadata: Additional information that you want to include when Auto Scaling sends a message to the notification target.
        :param pulumi.Input[str] scaling_group_id: The ID of the Auto Scaling group to which you want to assign the lifecycle hook.
        """
        if default_result is not None:
            pulumi.set(__self__, "default_result", default_result)
        if heartbeat_timeout is not None:
            pulumi.set(__self__, "heartbeat_timeout", heartbeat_timeout)
        if lifecycle_transition is not None:
            pulumi.set(__self__, "lifecycle_transition", lifecycle_transition)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if notification_arn is not None:
            pulumi.set(__self__, "notification_arn", notification_arn)
        if notification_metadata is not None:
            pulumi.set(__self__, "notification_metadata", notification_metadata)
        if scaling_group_id is not None:
            pulumi.set(__self__, "scaling_group_id", scaling_group_id)

    @property
    @pulumi.getter(name="defaultResult")
    def default_result(self) -> Optional[pulumi.Input[str]]:
        """
        Defines the action the Auto Scaling group should take when the lifecycle hook timeout elapses. Applicable value: CONTINUE, ABANDON, ROLLBACK, default value: CONTINUE.
        """
        return pulumi.get(self, "default_result")

    @default_result.setter
    def default_result(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "default_result", value)

    @property
    @pulumi.getter(name="heartbeatTimeout")
    def heartbeat_timeout(self) -> Optional[pulumi.Input[int]]:
        """
        Defines the amount of time, in seconds, that can elapse before the lifecycle hook times out. When the lifecycle hook times out, Auto Scaling performs the action defined in the default_result parameter. Default value: 600.
        """
        return pulumi.get(self, "heartbeat_timeout")

    @heartbeat_timeout.setter
    def heartbeat_timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "heartbeat_timeout", value)

    @property
    @pulumi.getter(name="lifecycleTransition")
    def lifecycle_transition(self) -> Optional[pulumi.Input[str]]:
        """
        Type of Scaling activity attached to lifecycle hook. Supported value: SCALE_OUT, SCALE_IN.
        """
        return pulumi.get(self, "lifecycle_transition")

    @lifecycle_transition.setter
    def lifecycle_transition(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lifecycle_transition", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the lifecycle hook, which must contain 2-64 characters (English or Chinese), starting with numbers, English letters or Chinese characters, and can contain number, underscores `_`, hypens `-`, and decimal point `.`. If this parameter value is not specified, the default value is lifecycle hook id.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="notificationArn")
    def notification_arn(self) -> Optional[pulumi.Input[str]]:
        """
        The Arn of notification target.
        """
        return pulumi.get(self, "notification_arn")

    @notification_arn.setter
    def notification_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "notification_arn", value)

    @property
    @pulumi.getter(name="notificationMetadata")
    def notification_metadata(self) -> Optional[pulumi.Input[str]]:
        """
        Additional information that you want to include when Auto Scaling sends a message to the notification target.
        """
        return pulumi.get(self, "notification_metadata")

    @notification_metadata.setter
    def notification_metadata(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "notification_metadata", value)

    @property
    @pulumi.getter(name="scalingGroupId")
    def scaling_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Auto Scaling group to which you want to assign the lifecycle hook.
        """
        return pulumi.get(self, "scaling_group_id")

    @scaling_group_id.setter
    def scaling_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "scaling_group_id", value)


class LifecycleHook(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 default_result: Optional[pulumi.Input[str]] = None,
                 heartbeat_timeout: Optional[pulumi.Input[int]] = None,
                 lifecycle_transition: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 notification_arn: Optional[pulumi.Input[str]] = None,
                 notification_metadata: Optional[pulumi.Input[str]] = None,
                 scaling_group_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a ESS lifecycle hook resource. More about Ess lifecycle hook, see [LifecycleHook](https://www.alibabacloud.com/help/doc-detail/73839.htm).

        > **NOTE:** Available since v1.13.0.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default_integer = random.index.Integer("default",
            min=10000,
            max=99999)
        my_name = f"{name}-{default_integer['result']}"
        default = alicloud.get_zones(available_disk_category="cloud_efficiency",
            available_resource_creation="VSwitch")
        default_network = alicloud.vpc.Network("default",
            vpc_name=my_name,
            cidr_block="172.16.0.0/16")
        default_switch = alicloud.vpc.Switch("default",
            vpc_id=default_network.id,
            cidr_block="172.16.0.0/24",
            zone_id=default.zones[0].id,
            vswitch_name=my_name)
        default2 = alicloud.vpc.Switch("default2",
            vpc_id=default_network.id,
            cidr_block="172.16.1.0/24",
            zone_id=default.zones[0].id,
            vswitch_name=f"{name}-bar")
        default_security_group = alicloud.ecs.SecurityGroup("default",
            name=my_name,
            vpc_id=default_network.id)
        default_scaling_group = alicloud.ess.ScalingGroup("default",
            min_size=1,
            max_size=1,
            scaling_group_name=my_name,
            default_cooldown=200,
            removal_policies=[
                "OldestInstance",
                "NewestInstance",
            ],
            vswitch_ids=[
                default_switch.id,
                default2.id,
            ])
        default_lifecycle_hook = alicloud.ess.LifecycleHook("default",
            scaling_group_id=default_scaling_group.id,
            name=my_name,
            lifecycle_transition="SCALE_OUT",
            heartbeat_timeout=400,
            notification_metadata="example")
        ```

        ## Module Support

        You can use to the existing autoscaling module
        to create a lifecycle hook, scaling group and configuration one-click.

        ## Import

        Ess lifecycle hook can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ess/lifecycleHook:LifecycleHook example ash-l12345
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] default_result: Defines the action the Auto Scaling group should take when the lifecycle hook timeout elapses. Applicable value: CONTINUE, ABANDON, ROLLBACK, default value: CONTINUE.
        :param pulumi.Input[int] heartbeat_timeout: Defines the amount of time, in seconds, that can elapse before the lifecycle hook times out. When the lifecycle hook times out, Auto Scaling performs the action defined in the default_result parameter. Default value: 600.
        :param pulumi.Input[str] lifecycle_transition: Type of Scaling activity attached to lifecycle hook. Supported value: SCALE_OUT, SCALE_IN.
        :param pulumi.Input[str] name: The name of the lifecycle hook, which must contain 2-64 characters (English or Chinese), starting with numbers, English letters or Chinese characters, and can contain number, underscores `_`, hypens `-`, and decimal point `.`. If this parameter value is not specified, the default value is lifecycle hook id.
        :param pulumi.Input[str] notification_arn: The Arn of notification target.
        :param pulumi.Input[str] notification_metadata: Additional information that you want to include when Auto Scaling sends a message to the notification target.
        :param pulumi.Input[str] scaling_group_id: The ID of the Auto Scaling group to which you want to assign the lifecycle hook.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LifecycleHookArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ESS lifecycle hook resource. More about Ess lifecycle hook, see [LifecycleHook](https://www.alibabacloud.com/help/doc-detail/73839.htm).

        > **NOTE:** Available since v1.13.0.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default_integer = random.index.Integer("default",
            min=10000,
            max=99999)
        my_name = f"{name}-{default_integer['result']}"
        default = alicloud.get_zones(available_disk_category="cloud_efficiency",
            available_resource_creation="VSwitch")
        default_network = alicloud.vpc.Network("default",
            vpc_name=my_name,
            cidr_block="172.16.0.0/16")
        default_switch = alicloud.vpc.Switch("default",
            vpc_id=default_network.id,
            cidr_block="172.16.0.0/24",
            zone_id=default.zones[0].id,
            vswitch_name=my_name)
        default2 = alicloud.vpc.Switch("default2",
            vpc_id=default_network.id,
            cidr_block="172.16.1.0/24",
            zone_id=default.zones[0].id,
            vswitch_name=f"{name}-bar")
        default_security_group = alicloud.ecs.SecurityGroup("default",
            name=my_name,
            vpc_id=default_network.id)
        default_scaling_group = alicloud.ess.ScalingGroup("default",
            min_size=1,
            max_size=1,
            scaling_group_name=my_name,
            default_cooldown=200,
            removal_policies=[
                "OldestInstance",
                "NewestInstance",
            ],
            vswitch_ids=[
                default_switch.id,
                default2.id,
            ])
        default_lifecycle_hook = alicloud.ess.LifecycleHook("default",
            scaling_group_id=default_scaling_group.id,
            name=my_name,
            lifecycle_transition="SCALE_OUT",
            heartbeat_timeout=400,
            notification_metadata="example")
        ```

        ## Module Support

        You can use to the existing autoscaling module
        to create a lifecycle hook, scaling group and configuration one-click.

        ## Import

        Ess lifecycle hook can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ess/lifecycleHook:LifecycleHook example ash-l12345
        ```

        :param str resource_name: The name of the resource.
        :param LifecycleHookArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LifecycleHookArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 default_result: Optional[pulumi.Input[str]] = None,
                 heartbeat_timeout: Optional[pulumi.Input[int]] = None,
                 lifecycle_transition: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 notification_arn: Optional[pulumi.Input[str]] = None,
                 notification_metadata: Optional[pulumi.Input[str]] = None,
                 scaling_group_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LifecycleHookArgs.__new__(LifecycleHookArgs)

            __props__.__dict__["default_result"] = default_result
            __props__.__dict__["heartbeat_timeout"] = heartbeat_timeout
            if lifecycle_transition is None and not opts.urn:
                raise TypeError("Missing required property 'lifecycle_transition'")
            __props__.__dict__["lifecycle_transition"] = lifecycle_transition
            __props__.__dict__["name"] = name
            __props__.__dict__["notification_arn"] = notification_arn
            __props__.__dict__["notification_metadata"] = notification_metadata
            if scaling_group_id is None and not opts.urn:
                raise TypeError("Missing required property 'scaling_group_id'")
            __props__.__dict__["scaling_group_id"] = scaling_group_id
        super(LifecycleHook, __self__).__init__(
            'alicloud:ess/lifecycleHook:LifecycleHook',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            default_result: Optional[pulumi.Input[str]] = None,
            heartbeat_timeout: Optional[pulumi.Input[int]] = None,
            lifecycle_transition: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            notification_arn: Optional[pulumi.Input[str]] = None,
            notification_metadata: Optional[pulumi.Input[str]] = None,
            scaling_group_id: Optional[pulumi.Input[str]] = None) -> 'LifecycleHook':
        """
        Get an existing LifecycleHook resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] default_result: Defines the action the Auto Scaling group should take when the lifecycle hook timeout elapses. Applicable value: CONTINUE, ABANDON, ROLLBACK, default value: CONTINUE.
        :param pulumi.Input[int] heartbeat_timeout: Defines the amount of time, in seconds, that can elapse before the lifecycle hook times out. When the lifecycle hook times out, Auto Scaling performs the action defined in the default_result parameter. Default value: 600.
        :param pulumi.Input[str] lifecycle_transition: Type of Scaling activity attached to lifecycle hook. Supported value: SCALE_OUT, SCALE_IN.
        :param pulumi.Input[str] name: The name of the lifecycle hook, which must contain 2-64 characters (English or Chinese), starting with numbers, English letters or Chinese characters, and can contain number, underscores `_`, hypens `-`, and decimal point `.`. If this parameter value is not specified, the default value is lifecycle hook id.
        :param pulumi.Input[str] notification_arn: The Arn of notification target.
        :param pulumi.Input[str] notification_metadata: Additional information that you want to include when Auto Scaling sends a message to the notification target.
        :param pulumi.Input[str] scaling_group_id: The ID of the Auto Scaling group to which you want to assign the lifecycle hook.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LifecycleHookState.__new__(_LifecycleHookState)

        __props__.__dict__["default_result"] = default_result
        __props__.__dict__["heartbeat_timeout"] = heartbeat_timeout
        __props__.__dict__["lifecycle_transition"] = lifecycle_transition
        __props__.__dict__["name"] = name
        __props__.__dict__["notification_arn"] = notification_arn
        __props__.__dict__["notification_metadata"] = notification_metadata
        __props__.__dict__["scaling_group_id"] = scaling_group_id
        return LifecycleHook(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="defaultResult")
    def default_result(self) -> pulumi.Output[Optional[str]]:
        """
        Defines the action the Auto Scaling group should take when the lifecycle hook timeout elapses. Applicable value: CONTINUE, ABANDON, ROLLBACK, default value: CONTINUE.
        """
        return pulumi.get(self, "default_result")

    @property
    @pulumi.getter(name="heartbeatTimeout")
    def heartbeat_timeout(self) -> pulumi.Output[Optional[int]]:
        """
        Defines the amount of time, in seconds, that can elapse before the lifecycle hook times out. When the lifecycle hook times out, Auto Scaling performs the action defined in the default_result parameter. Default value: 600.
        """
        return pulumi.get(self, "heartbeat_timeout")

    @property
    @pulumi.getter(name="lifecycleTransition")
    def lifecycle_transition(self) -> pulumi.Output[str]:
        """
        Type of Scaling activity attached to lifecycle hook. Supported value: SCALE_OUT, SCALE_IN.
        """
        return pulumi.get(self, "lifecycle_transition")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the lifecycle hook, which must contain 2-64 characters (English or Chinese), starting with numbers, English letters or Chinese characters, and can contain number, underscores `_`, hypens `-`, and decimal point `.`. If this parameter value is not specified, the default value is lifecycle hook id.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="notificationArn")
    def notification_arn(self) -> pulumi.Output[str]:
        """
        The Arn of notification target.
        """
        return pulumi.get(self, "notification_arn")

    @property
    @pulumi.getter(name="notificationMetadata")
    def notification_metadata(self) -> pulumi.Output[str]:
        """
        Additional information that you want to include when Auto Scaling sends a message to the notification target.
        """
        return pulumi.get(self, "notification_metadata")

    @property
    @pulumi.getter(name="scalingGroupId")
    def scaling_group_id(self) -> pulumi.Output[str]:
        """
        The ID of the Auto Scaling group to which you want to assign the lifecycle hook.
        """
        return pulumi.get(self, "scaling_group_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['VvpInstanceArgs', 'VvpInstance']

@pulumi.input_type
class VvpInstanceArgs:
    def __init__(__self__, *,
                 payment_type: pulumi.Input[str],
                 storage: pulumi.Input['VvpInstanceStorageArgs'],
                 vpc_id: pulumi.Input[str],
                 vswitch_ids: pulumi.Input[Sequence[pulumi.Input[str]]],
                 vvp_instance_name: pulumi.Input[str],
                 zone_id: pulumi.Input[str],
                 duration: Optional[pulumi.Input[int]] = None,
                 pricing_cycle: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 resource_spec: Optional[pulumi.Input['VvpInstanceResourceSpecArgs']] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a VvpInstance resource.
        :param pulumi.Input[str] payment_type: The payment type of the resource.
        :param pulumi.Input['VvpInstanceStorageArgs'] storage: Store information. See `storage` below.
        :param pulumi.Input[str] vpc_id: The VPC ID of the user.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] vswitch_ids: Virtual Switch ID.
        :param pulumi.Input[str] vvp_instance_name: The name of the workspace.
        :param pulumi.Input[str] zone_id: The zone ID of the resource.
        :param pulumi.Input[int] duration: The number of subscription periods. If the payment type is PRE, this parameter is required.
        :param pulumi.Input[str] pricing_cycle: The subscription period. If the payment type is PRE, this parameter is required.
        :param pulumi.Input[str] resource_group_id: The resource group to which the newly purchased instance belongs.
        :param pulumi.Input['VvpInstanceResourceSpecArgs'] resource_spec: Resource specifications. See `resource_spec` below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: The tags of the resource.
        """
        pulumi.set(__self__, "payment_type", payment_type)
        pulumi.set(__self__, "storage", storage)
        pulumi.set(__self__, "vpc_id", vpc_id)
        pulumi.set(__self__, "vswitch_ids", vswitch_ids)
        pulumi.set(__self__, "vvp_instance_name", vvp_instance_name)
        pulumi.set(__self__, "zone_id", zone_id)
        if duration is not None:
            pulumi.set(__self__, "duration", duration)
        if pricing_cycle is not None:
            pulumi.set(__self__, "pricing_cycle", pricing_cycle)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if resource_spec is not None:
            pulumi.set(__self__, "resource_spec", resource_spec)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Input[str]:
        """
        The payment type of the resource.
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter
    def storage(self) -> pulumi.Input['VvpInstanceStorageArgs']:
        """
        Store information. See `storage` below.
        """
        return pulumi.get(self, "storage")

    @storage.setter
    def storage(self, value: pulumi.Input['VvpInstanceStorageArgs']):
        pulumi.set(self, "storage", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[str]:
        """
        The VPC ID of the user.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vswitchIds")
    def vswitch_ids(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        Virtual Switch ID.
        """
        return pulumi.get(self, "vswitch_ids")

    @vswitch_ids.setter
    def vswitch_ids(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "vswitch_ids", value)

    @property
    @pulumi.getter(name="vvpInstanceName")
    def vvp_instance_name(self) -> pulumi.Input[str]:
        """
        The name of the workspace.
        """
        return pulumi.get(self, "vvp_instance_name")

    @vvp_instance_name.setter
    def vvp_instance_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "vvp_instance_name", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Input[str]:
        """
        The zone ID of the resource.
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "zone_id", value)

    @property
    @pulumi.getter
    def duration(self) -> Optional[pulumi.Input[int]]:
        """
        The number of subscription periods. If the payment type is PRE, this parameter is required.
        """
        return pulumi.get(self, "duration")

    @duration.setter
    def duration(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "duration", value)

    @property
    @pulumi.getter(name="pricingCycle")
    def pricing_cycle(self) -> Optional[pulumi.Input[str]]:
        """
        The subscription period. If the payment type is PRE, this parameter is required.
        """
        return pulumi.get(self, "pricing_cycle")

    @pricing_cycle.setter
    def pricing_cycle(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pricing_cycle", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The resource group to which the newly purchased instance belongs.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter(name="resourceSpec")
    def resource_spec(self) -> Optional[pulumi.Input['VvpInstanceResourceSpecArgs']]:
        """
        Resource specifications. See `resource_spec` below.
        """
        return pulumi.get(self, "resource_spec")

    @resource_spec.setter
    def resource_spec(self, value: Optional[pulumi.Input['VvpInstanceResourceSpecArgs']]):
        pulumi.set(self, "resource_spec", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        The tags of the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _VvpInstanceState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[str]] = None,
                 duration: Optional[pulumi.Input[int]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 pricing_cycle: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 resource_spec: Optional[pulumi.Input['VvpInstanceResourceSpecArgs']] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 storage: Optional[pulumi.Input['VvpInstanceStorageArgs']] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vswitch_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 vvp_instance_name: Optional[pulumi.Input[str]] = None,
                 zone_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering VvpInstance resources.
        :param pulumi.Input[str] create_time: The creation time of the resource.
        :param pulumi.Input[int] duration: The number of subscription periods. If the payment type is PRE, this parameter is required.
        :param pulumi.Input[str] payment_type: The payment type of the resource.
        :param pulumi.Input[str] pricing_cycle: The subscription period. If the payment type is PRE, this parameter is required.
        :param pulumi.Input[str] resource_group_id: The resource group to which the newly purchased instance belongs.
        :param pulumi.Input['VvpInstanceResourceSpecArgs'] resource_spec: Resource specifications. See `resource_spec` below.
        :param pulumi.Input[str] status: The status of the resource.
        :param pulumi.Input['VvpInstanceStorageArgs'] storage: Store information. See `storage` below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: The tags of the resource.
        :param pulumi.Input[str] vpc_id: The VPC ID of the user.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] vswitch_ids: Virtual Switch ID.
        :param pulumi.Input[str] vvp_instance_name: The name of the workspace.
        :param pulumi.Input[str] zone_id: The zone ID of the resource.
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if duration is not None:
            pulumi.set(__self__, "duration", duration)
        if payment_type is not None:
            pulumi.set(__self__, "payment_type", payment_type)
        if pricing_cycle is not None:
            pulumi.set(__self__, "pricing_cycle", pricing_cycle)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if resource_spec is not None:
            pulumi.set(__self__, "resource_spec", resource_spec)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if storage is not None:
            pulumi.set(__self__, "storage", storage)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if vswitch_ids is not None:
            pulumi.set(__self__, "vswitch_ids", vswitch_ids)
        if vvp_instance_name is not None:
            pulumi.set(__self__, "vvp_instance_name", vvp_instance_name)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        The creation time of the resource.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def duration(self) -> Optional[pulumi.Input[int]]:
        """
        The number of subscription periods. If the payment type is PRE, this parameter is required.
        """
        return pulumi.get(self, "duration")

    @duration.setter
    def duration(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "duration", value)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> Optional[pulumi.Input[str]]:
        """
        The payment type of the resource.
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter(name="pricingCycle")
    def pricing_cycle(self) -> Optional[pulumi.Input[str]]:
        """
        The subscription period. If the payment type is PRE, this parameter is required.
        """
        return pulumi.get(self, "pricing_cycle")

    @pricing_cycle.setter
    def pricing_cycle(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pricing_cycle", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The resource group to which the newly purchased instance belongs.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter(name="resourceSpec")
    def resource_spec(self) -> Optional[pulumi.Input['VvpInstanceResourceSpecArgs']]:
        """
        Resource specifications. See `resource_spec` below.
        """
        return pulumi.get(self, "resource_spec")

    @resource_spec.setter
    def resource_spec(self, value: Optional[pulumi.Input['VvpInstanceResourceSpecArgs']]):
        pulumi.set(self, "resource_spec", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def storage(self) -> Optional[pulumi.Input['VvpInstanceStorageArgs']]:
        """
        Store information. See `storage` below.
        """
        return pulumi.get(self, "storage")

    @storage.setter
    def storage(self, value: Optional[pulumi.Input['VvpInstanceStorageArgs']]):
        pulumi.set(self, "storage", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        The tags of the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[str]]:
        """
        The VPC ID of the user.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vswitchIds")
    def vswitch_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Virtual Switch ID.
        """
        return pulumi.get(self, "vswitch_ids")

    @vswitch_ids.setter
    def vswitch_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "vswitch_ids", value)

    @property
    @pulumi.getter(name="vvpInstanceName")
    def vvp_instance_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the workspace.
        """
        return pulumi.get(self, "vvp_instance_name")

    @vvp_instance_name.setter
    def vvp_instance_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vvp_instance_name", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[str]]:
        """
        The zone ID of the resource.
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "zone_id", value)


class VvpInstance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 duration: Optional[pulumi.Input[int]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 pricing_cycle: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 resource_spec: Optional[pulumi.Input[Union['VvpInstanceResourceSpecArgs', 'VvpInstanceResourceSpecArgsDict']]] = None,
                 storage: Optional[pulumi.Input[Union['VvpInstanceStorageArgs', 'VvpInstanceStorageArgsDict']]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vswitch_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 vvp_instance_name: Optional[pulumi.Input[str]] = None,
                 zone_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## Import

        Realtime Compute Vvp Instance can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:realtimecompute/vvpInstance:VvpInstance example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] duration: The number of subscription periods. If the payment type is PRE, this parameter is required.
        :param pulumi.Input[str] payment_type: The payment type of the resource.
        :param pulumi.Input[str] pricing_cycle: The subscription period. If the payment type is PRE, this parameter is required.
        :param pulumi.Input[str] resource_group_id: The resource group to which the newly purchased instance belongs.
        :param pulumi.Input[Union['VvpInstanceResourceSpecArgs', 'VvpInstanceResourceSpecArgsDict']] resource_spec: Resource specifications. See `resource_spec` below.
        :param pulumi.Input[Union['VvpInstanceStorageArgs', 'VvpInstanceStorageArgsDict']] storage: Store information. See `storage` below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: The tags of the resource.
        :param pulumi.Input[str] vpc_id: The VPC ID of the user.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] vswitch_ids: Virtual Switch ID.
        :param pulumi.Input[str] vvp_instance_name: The name of the workspace.
        :param pulumi.Input[str] zone_id: The zone ID of the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VvpInstanceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        Realtime Compute Vvp Instance can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:realtimecompute/vvpInstance:VvpInstance example <id>
        ```

        :param str resource_name: The name of the resource.
        :param VvpInstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VvpInstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 duration: Optional[pulumi.Input[int]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 pricing_cycle: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 resource_spec: Optional[pulumi.Input[Union['VvpInstanceResourceSpecArgs', 'VvpInstanceResourceSpecArgsDict']]] = None,
                 storage: Optional[pulumi.Input[Union['VvpInstanceStorageArgs', 'VvpInstanceStorageArgsDict']]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vswitch_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 vvp_instance_name: Optional[pulumi.Input[str]] = None,
                 zone_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VvpInstanceArgs.__new__(VvpInstanceArgs)

            __props__.__dict__["duration"] = duration
            if payment_type is None and not opts.urn:
                raise TypeError("Missing required property 'payment_type'")
            __props__.__dict__["payment_type"] = payment_type
            __props__.__dict__["pricing_cycle"] = pricing_cycle
            __props__.__dict__["resource_group_id"] = resource_group_id
            __props__.__dict__["resource_spec"] = resource_spec
            if storage is None and not opts.urn:
                raise TypeError("Missing required property 'storage'")
            __props__.__dict__["storage"] = storage
            __props__.__dict__["tags"] = tags
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            if vswitch_ids is None and not opts.urn:
                raise TypeError("Missing required property 'vswitch_ids'")
            __props__.__dict__["vswitch_ids"] = vswitch_ids
            if vvp_instance_name is None and not opts.urn:
                raise TypeError("Missing required property 'vvp_instance_name'")
            __props__.__dict__["vvp_instance_name"] = vvp_instance_name
            if zone_id is None and not opts.urn:
                raise TypeError("Missing required property 'zone_id'")
            __props__.__dict__["zone_id"] = zone_id
            __props__.__dict__["create_time"] = None
            __props__.__dict__["status"] = None
        super(VvpInstance, __self__).__init__(
            'alicloud:realtimecompute/vvpInstance:VvpInstance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            duration: Optional[pulumi.Input[int]] = None,
            payment_type: Optional[pulumi.Input[str]] = None,
            pricing_cycle: Optional[pulumi.Input[str]] = None,
            resource_group_id: Optional[pulumi.Input[str]] = None,
            resource_spec: Optional[pulumi.Input[Union['VvpInstanceResourceSpecArgs', 'VvpInstanceResourceSpecArgsDict']]] = None,
            status: Optional[pulumi.Input[str]] = None,
            storage: Optional[pulumi.Input[Union['VvpInstanceStorageArgs', 'VvpInstanceStorageArgsDict']]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            vpc_id: Optional[pulumi.Input[str]] = None,
            vswitch_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            vvp_instance_name: Optional[pulumi.Input[str]] = None,
            zone_id: Optional[pulumi.Input[str]] = None) -> 'VvpInstance':
        """
        Get an existing VvpInstance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] create_time: The creation time of the resource.
        :param pulumi.Input[int] duration: The number of subscription periods. If the payment type is PRE, this parameter is required.
        :param pulumi.Input[str] payment_type: The payment type of the resource.
        :param pulumi.Input[str] pricing_cycle: The subscription period. If the payment type is PRE, this parameter is required.
        :param pulumi.Input[str] resource_group_id: The resource group to which the newly purchased instance belongs.
        :param pulumi.Input[Union['VvpInstanceResourceSpecArgs', 'VvpInstanceResourceSpecArgsDict']] resource_spec: Resource specifications. See `resource_spec` below.
        :param pulumi.Input[str] status: The status of the resource.
        :param pulumi.Input[Union['VvpInstanceStorageArgs', 'VvpInstanceStorageArgsDict']] storage: Store information. See `storage` below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: The tags of the resource.
        :param pulumi.Input[str] vpc_id: The VPC ID of the user.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] vswitch_ids: Virtual Switch ID.
        :param pulumi.Input[str] vvp_instance_name: The name of the workspace.
        :param pulumi.Input[str] zone_id: The zone ID of the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VvpInstanceState.__new__(_VvpInstanceState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["duration"] = duration
        __props__.__dict__["payment_type"] = payment_type
        __props__.__dict__["pricing_cycle"] = pricing_cycle
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["resource_spec"] = resource_spec
        __props__.__dict__["status"] = status
        __props__.__dict__["storage"] = storage
        __props__.__dict__["tags"] = tags
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["vswitch_ids"] = vswitch_ids
        __props__.__dict__["vvp_instance_name"] = vvp_instance_name
        __props__.__dict__["zone_id"] = zone_id
        return VvpInstance(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        The creation time of the resource.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def duration(self) -> pulumi.Output[Optional[int]]:
        """
        The number of subscription periods. If the payment type is PRE, this parameter is required.
        """
        return pulumi.get(self, "duration")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Output[str]:
        """
        The payment type of the resource.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter(name="pricingCycle")
    def pricing_cycle(self) -> pulumi.Output[Optional[str]]:
        """
        The subscription period. If the payment type is PRE, this parameter is required.
        """
        return pulumi.get(self, "pricing_cycle")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[str]:
        """
        The resource group to which the newly purchased instance belongs.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="resourceSpec")
    def resource_spec(self) -> pulumi.Output['outputs.VvpInstanceResourceSpec']:
        """
        Resource specifications. See `resource_spec` below.
        """
        return pulumi.get(self, "resource_spec")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def storage(self) -> pulumi.Output['outputs.VvpInstanceStorage']:
        """
        Store information. See `storage` below.
        """
        return pulumi.get(self, "storage")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        The tags of the resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[str]:
        """
        The VPC ID of the user.
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vswitchIds")
    def vswitch_ids(self) -> pulumi.Output[Sequence[str]]:
        """
        Virtual Switch ID.
        """
        return pulumi.get(self, "vswitch_ids")

    @property
    @pulumi.getter(name="vvpInstanceName")
    def vvp_instance_name(self) -> pulumi.Output[str]:
        """
        The name of the workspace.
        """
        return pulumi.get(self, "vvp_instance_name")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Output[str]:
        """
        The zone ID of the resource.
        """
        return pulumi.get(self, "zone_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['StoreIndexArgs', 'StoreIndex']

@pulumi.input_type
class StoreIndexArgs:
    def __init__(__self__, *,
                 logstore: pulumi.Input[str],
                 project: pulumi.Input[str],
                 field_searches: Optional[pulumi.Input[Sequence[pulumi.Input['StoreIndexFieldSearchArgs']]]] = None,
                 full_text: Optional[pulumi.Input['StoreIndexFullTextArgs']] = None):
        """
        The set of arguments for constructing a StoreIndex resource.
        :param pulumi.Input[str] logstore: The log store name to the query index belongs.
        :param pulumi.Input[str] project: The project name to the log store belongs.
        :param pulumi.Input[Sequence[pulumi.Input['StoreIndexFieldSearchArgs']]] field_searches: List configurations of field search index. Valid item as follows:
        :param pulumi.Input['StoreIndexFullTextArgs'] full_text: The configuration of full text index. Valid item as follows:
        """
        pulumi.set(__self__, "logstore", logstore)
        pulumi.set(__self__, "project", project)
        if field_searches is not None:
            pulumi.set(__self__, "field_searches", field_searches)
        if full_text is not None:
            pulumi.set(__self__, "full_text", full_text)

    @property
    @pulumi.getter
    def logstore(self) -> pulumi.Input[str]:
        """
        The log store name to the query index belongs.
        """
        return pulumi.get(self, "logstore")

    @logstore.setter
    def logstore(self, value: pulumi.Input[str]):
        pulumi.set(self, "logstore", value)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        The project name to the log store belongs.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="fieldSearches")
    def field_searches(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['StoreIndexFieldSearchArgs']]]]:
        """
        List configurations of field search index. Valid item as follows:
        """
        return pulumi.get(self, "field_searches")

    @field_searches.setter
    def field_searches(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['StoreIndexFieldSearchArgs']]]]):
        pulumi.set(self, "field_searches", value)

    @property
    @pulumi.getter(name="fullText")
    def full_text(self) -> Optional[pulumi.Input['StoreIndexFullTextArgs']]:
        """
        The configuration of full text index. Valid item as follows:
        """
        return pulumi.get(self, "full_text")

    @full_text.setter
    def full_text(self, value: Optional[pulumi.Input['StoreIndexFullTextArgs']]):
        pulumi.set(self, "full_text", value)


@pulumi.input_type
class _StoreIndexState:
    def __init__(__self__, *,
                 field_searches: Optional[pulumi.Input[Sequence[pulumi.Input['StoreIndexFieldSearchArgs']]]] = None,
                 full_text: Optional[pulumi.Input['StoreIndexFullTextArgs']] = None,
                 logstore: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering StoreIndex resources.
        :param pulumi.Input[Sequence[pulumi.Input['StoreIndexFieldSearchArgs']]] field_searches: List configurations of field search index. Valid item as follows:
        :param pulumi.Input['StoreIndexFullTextArgs'] full_text: The configuration of full text index. Valid item as follows:
        :param pulumi.Input[str] logstore: The log store name to the query index belongs.
        :param pulumi.Input[str] project: The project name to the log store belongs.
        """
        if field_searches is not None:
            pulumi.set(__self__, "field_searches", field_searches)
        if full_text is not None:
            pulumi.set(__self__, "full_text", full_text)
        if logstore is not None:
            pulumi.set(__self__, "logstore", logstore)
        if project is not None:
            pulumi.set(__self__, "project", project)

    @property
    @pulumi.getter(name="fieldSearches")
    def field_searches(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['StoreIndexFieldSearchArgs']]]]:
        """
        List configurations of field search index. Valid item as follows:
        """
        return pulumi.get(self, "field_searches")

    @field_searches.setter
    def field_searches(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['StoreIndexFieldSearchArgs']]]]):
        pulumi.set(self, "field_searches", value)

    @property
    @pulumi.getter(name="fullText")
    def full_text(self) -> Optional[pulumi.Input['StoreIndexFullTextArgs']]:
        """
        The configuration of full text index. Valid item as follows:
        """
        return pulumi.get(self, "full_text")

    @full_text.setter
    def full_text(self, value: Optional[pulumi.Input['StoreIndexFullTextArgs']]):
        pulumi.set(self, "full_text", value)

    @property
    @pulumi.getter
    def logstore(self) -> Optional[pulumi.Input[str]]:
        """
        The log store name to the query index belongs.
        """
        return pulumi.get(self, "logstore")

    @logstore.setter
    def logstore(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "logstore", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The project name to the log store belongs.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)


class StoreIndex(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 field_searches: Optional[pulumi.Input[Sequence[pulumi.Input[Union['StoreIndexFieldSearchArgs', 'StoreIndexFieldSearchArgsDict']]]]] = None,
                 full_text: Optional[pulumi.Input[Union['StoreIndexFullTextArgs', 'StoreIndexFullTextArgsDict']]] = None,
                 logstore: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Log Service provides the LogSearch/Analytics function to query and analyze large amounts of logs in real time.
        You can use this function by enabling the index and field statistics. [Refer to details](https://www.alibabacloud.com/help/doc-detail/43772.htm)

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        default = random.index.Integer("default",
            max=99999,
            min=10000)
        example = alicloud.log.Project("example",
            project_name=f"terraform-example-{default['result']}",
            description="terraform-example")
        example_store = alicloud.log.Store("example",
            project_name=example.project_name,
            logstore_name="example-store",
            shard_count=3,
            auto_split=True,
            max_split_shard_count=60,
            append_meta=True)
        example_store_index = alicloud.log.StoreIndex("example",
            project=example.project_name,
            logstore=example_store.logstore_name,
            full_text={
                "case_sensitive": True,
                "token": \"\"\" #$^*\\x0d
        \\x09\"\"\",
            },
            field_searches=[{
                "name": "terraform-example",
                "enable_analytics": True,
                "type": "text",
                "token": \"\"\" #$^*\\x0d
        \\x09\"\"\",
            }])
        ```

        ## Module Support

        You can use the existing sls module
        to create SLS project, store and store index one-click, like ECS instances.

        ## Import

        Log store index can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:log/storeIndex:StoreIndex example tf-log:tf-log-store
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['StoreIndexFieldSearchArgs', 'StoreIndexFieldSearchArgsDict']]]] field_searches: List configurations of field search index. Valid item as follows:
        :param pulumi.Input[Union['StoreIndexFullTextArgs', 'StoreIndexFullTextArgsDict']] full_text: The configuration of full text index. Valid item as follows:
        :param pulumi.Input[str] logstore: The log store name to the query index belongs.
        :param pulumi.Input[str] project: The project name to the log store belongs.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: StoreIndexArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Log Service provides the LogSearch/Analytics function to query and analyze large amounts of logs in real time.
        You can use this function by enabling the index and field statistics. [Refer to details](https://www.alibabacloud.com/help/doc-detail/43772.htm)

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        default = random.index.Integer("default",
            max=99999,
            min=10000)
        example = alicloud.log.Project("example",
            project_name=f"terraform-example-{default['result']}",
            description="terraform-example")
        example_store = alicloud.log.Store("example",
            project_name=example.project_name,
            logstore_name="example-store",
            shard_count=3,
            auto_split=True,
            max_split_shard_count=60,
            append_meta=True)
        example_store_index = alicloud.log.StoreIndex("example",
            project=example.project_name,
            logstore=example_store.logstore_name,
            full_text={
                "case_sensitive": True,
                "token": \"\"\" #$^*\\x0d
        \\x09\"\"\",
            },
            field_searches=[{
                "name": "terraform-example",
                "enable_analytics": True,
                "type": "text",
                "token": \"\"\" #$^*\\x0d
        \\x09\"\"\",
            }])
        ```

        ## Module Support

        You can use the existing sls module
        to create SLS project, store and store index one-click, like ECS instances.

        ## Import

        Log store index can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:log/storeIndex:StoreIndex example tf-log:tf-log-store
        ```

        :param str resource_name: The name of the resource.
        :param StoreIndexArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(StoreIndexArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 field_searches: Optional[pulumi.Input[Sequence[pulumi.Input[Union['StoreIndexFieldSearchArgs', 'StoreIndexFieldSearchArgsDict']]]]] = None,
                 full_text: Optional[pulumi.Input[Union['StoreIndexFullTextArgs', 'StoreIndexFullTextArgsDict']]] = None,
                 logstore: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = StoreIndexArgs.__new__(StoreIndexArgs)

            __props__.__dict__["field_searches"] = field_searches
            __props__.__dict__["full_text"] = full_text
            if logstore is None and not opts.urn:
                raise TypeError("Missing required property 'logstore'")
            __props__.__dict__["logstore"] = logstore
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
        super(StoreIndex, __self__).__init__(
            'alicloud:log/storeIndex:StoreIndex',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            field_searches: Optional[pulumi.Input[Sequence[pulumi.Input[Union['StoreIndexFieldSearchArgs', 'StoreIndexFieldSearchArgsDict']]]]] = None,
            full_text: Optional[pulumi.Input[Union['StoreIndexFullTextArgs', 'StoreIndexFullTextArgsDict']]] = None,
            logstore: Optional[pulumi.Input[str]] = None,
            project: Optional[pulumi.Input[str]] = None) -> 'StoreIndex':
        """
        Get an existing StoreIndex resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['StoreIndexFieldSearchArgs', 'StoreIndexFieldSearchArgsDict']]]] field_searches: List configurations of field search index. Valid item as follows:
        :param pulumi.Input[Union['StoreIndexFullTextArgs', 'StoreIndexFullTextArgsDict']] full_text: The configuration of full text index. Valid item as follows:
        :param pulumi.Input[str] logstore: The log store name to the query index belongs.
        :param pulumi.Input[str] project: The project name to the log store belongs.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _StoreIndexState.__new__(_StoreIndexState)

        __props__.__dict__["field_searches"] = field_searches
        __props__.__dict__["full_text"] = full_text
        __props__.__dict__["logstore"] = logstore
        __props__.__dict__["project"] = project
        return StoreIndex(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="fieldSearches")
    def field_searches(self) -> pulumi.Output[Optional[Sequence['outputs.StoreIndexFieldSearch']]]:
        """
        List configurations of field search index. Valid item as follows:
        """
        return pulumi.get(self, "field_searches")

    @property
    @pulumi.getter(name="fullText")
    def full_text(self) -> pulumi.Output[Optional['outputs.StoreIndexFullText']]:
        """
        The configuration of full text index. Valid item as follows:
        """
        return pulumi.get(self, "full_text")

    @property
    @pulumi.getter
    def logstore(self) -> pulumi.Output[str]:
        """
        The log store name to the query index belongs.
        """
        return pulumi.get(self, "logstore")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        The project name to the log store belongs.
        """
        return pulumi.get(self, "project")

